pub enum LoopMode {
None,
Loop,
LoopAndReshuffle,
RepeatTrack,
}Variants
None
Disables looping
Loop
When the end of the tracklist is reached, loop back to the beginning
LoopAndReshuffle
When the end of the tracklist is reached, reshuffle the tracklist using the shuffle mode and loop
RepeatTrack
When the end of the current track is reached, repeat