#[repr(u8)]pub enum PacketType {
Unknown = 0,
Event = 1,
Response = 2,
Error = 3,
Disconnect = 4,
}Variants
Unknown = 0
Unknown packet. Either the client is out of date, or the daemon has a logic bug
Event = 1
An event, can be sent without input
Response = 2
A response to a command
Error = 3
Disconnect = 4
Client has been disconnected from the daemon. This can happen from a manual disconnect, or from the daemon shutting down