pub enum ShuffleMode {
None,
CollectionsOnly,
TracksOnly,
CollectionsAndTracks,
Full,
}Variants
None
Tracks are not shuffled, they are played as is
CollectionsOnly
Only collections are shuffled, meaning the collections are shuffled, but not the contents
TracksOnly
Randomize tracks only, meaning the contents of collections are shuffled, but not the collections themselves
CollectionsAndTracks
Randomize collection order and the tracks inside the collection
Full
Randomizes the order of everything